@@ -204,6 +204,7 @@ void gauaw(int kn, double *pl, double *pw)
   return;
 }
 
+#if 0
 static
 void gauaw_old(double *pa, double *pw, int nlat)
 {
@@ -294,7 +295,7 @@ void gauaw_old(double *pa, double *pw, int nlat)
 
   return;
 }
-
+#endif
 
 void gaussaw(double *pa, double *pw, int nlat)
 {
@@ -315,12 +316,26 @@ int main (int rgc, char *argv[])
 
   gauaw(ngl, pl, pw);
   gauaw_old(plo, pwo, ngl);
+  for (i = 0; i < ngl; i++)
+    {
+      pl[i]  = asin(pl[i])/M_PI*180.0;
+      plo[i] = asin(plo[i])/M_PI*180.0;
+    }
 
   for (i = 0; i < ngl; i++)
     {
-      fprintf(stderr, "%4d%25.18f%25.18f%25.18f%25.18f\n", i, pl[i], pw[i], pl[i]-plo[i], pw[i]-pwo[i]);
+      fprintf(stderr, "%4d%25.18f%25.18f%25.18f%25.18f\n", i+1, pl[i], pw[i], pl[i]-plo[i], pw[i]-pwo[i]);
     }
 
   return 0;
 }
 */
+/*
+ * Local Variables:
+ * c-file-style: "Java"
+ * c-basic-offset: 2
+ * indent-tabs-mode: nil
+ * show-trailing-whitespace: t
+ * require-trailing-newline: t
+ * End:
+ */
