@@ -23,7 +23,7 @@ int grib1ltypeToZaxisType(int grib_ltype)
   switch ( grib_ltype )
     {
     case GRIB1_LTYPE_SURFACE:         { zaxistype = ZAXIS_SURFACE;           break; }
-    case GRIB1_LTYPE_TOA:     { zaxistype = ZAXIS_TOA;       break; }
+    case GRIB1_LTYPE_TOA:             { zaxistype = ZAXIS_TOA;               break; }
     case GRIB1_LTYPE_SEA_BOTTOM:      { zaxistype = ZAXIS_SEA_BOTTOM;        break; }
     case GRIB1_LTYPE_ATMOSPHERE:      { zaxistype = ZAXIS_ATMOSPHERE;        break; }
     case GRIB1_LTYPE_MEANSEA:         { zaxistype = ZAXIS_MEANSEA;           break; }
@@ -31,7 +31,8 @@ int grib1ltypeToZaxisType(int grib_ltype)
     case GRIB1_LTYPE_ISOBARIC:        { zaxistype = ZAXIS_PRESSURE;          break; }
     case GRIB1_LTYPE_HEIGHT:          { zaxistype = ZAXIS_HEIGHT;            break; }
     case GRIB1_LTYPE_ALTITUDE:        { zaxistype = ZAXIS_ALTITUDE;	     break; }
-    case GRIB1_LTYPE_SIGMA:           { zaxistype = ZAXIS_SIGMA;	     break; }
+    case GRIB1_LTYPE_SIGMA:
+    case GRIB1_LTYPE_SIGMA_LAYER:     { zaxistype = ZAXIS_SIGMA;	     break; }
     case GRIB1_LTYPE_HYBRID:
     case GRIB1_LTYPE_HYBRID_LAYER:    { zaxistype = ZAXIS_HYBRID;	     break; }
     case GRIB1_LTYPE_LANDDEPTH:
@@ -51,7 +52,7 @@ int grib2ltypeToZaxisType(int grib_ltype)
   switch ( grib_ltype )
     {
     case GRIB2_LTYPE_SURFACE:            { zaxistype = ZAXIS_SURFACE;           break; }
-    case GRIB2_LTYPE_TOA:        { zaxistype = ZAXIS_TOA;       break; }
+    case GRIB2_LTYPE_TOA:                { zaxistype = ZAXIS_TOA;               break; }
     case GRIB2_LTYPE_SEA_BOTTOM:         { zaxistype = ZAXIS_SEA_BOTTOM;        break; }
     case GRIB2_LTYPE_ATMOSPHERE:         { zaxistype = ZAXIS_ATMOSPHERE;        break; }
     case GRIB2_LTYPE_MEANSEA:            { zaxistype = ZAXIS_MEANSEA;           break; }
@@ -443,24 +444,28 @@ void grbReadVarSliceDP(int streamID, int varID, int levelID, double *data, int *
 static
 size_t grbEncode(int filetype, int varID, int levelID, int vlistID, int gridID, int zaxisID,
 		 int date, int time, int tsteptype, int numavg, 
-		 long datasize, const double *data, int nmiss, unsigned char *gribbuffer, size_t gribbuffersize,
+		 long datasize, const double *data, int nmiss, unsigned char **gribbuffer,
 		 int ljpeg, void *gribContainer)
 {
   size_t nbytes;
+  size_t gribbuffersize;
 
 #if  defined  (HAVE_LIBCGRIBEX)
   if ( filetype == FILETYPE_GRB )
     {
+      gribbuffersize = datasize*4+3000;
+      *gribbuffer = (unsigned char *) malloc(gribbuffersize);
+
       nbytes = cgribexEncode(varID, levelID, vlistID, gridID, zaxisID,
 			     date, time, tsteptype, numavg, 
-			     datasize, data, nmiss, gribbuffer, gribbuffersize);
+			     datasize, data, nmiss, *gribbuffer, gribbuffersize);
     }
   else
 #endif
     {
       nbytes = gribapiEncode(varID, levelID, vlistID, gridID, zaxisID,
 			     date, time, tsteptype, numavg, 
-			     datasize, data, nmiss, gribbuffer, gribbuffersize,
+			     datasize, data, nmiss, gribbuffer, &gribbuffersize,
 			     ljpeg, gribContainer);
     }
 
@@ -504,7 +509,6 @@ int grbWriteVarSliceDP(int streamID, int varID, int levelID, const double *data,
   int gridID;
   int zaxisID;
   unsigned char *gribbuffer = NULL;
-  size_t gribbuffersize = 0;
   long datasize;
   int tsID;
   int vlistID;
@@ -540,10 +544,10 @@ int grbWriteVarSliceDP(int streamID, int varID, int levelID, const double *data,
     Message("gridID = %d zaxisID = %d", gridID, zaxisID);
 
   datasize = gridInqSize(gridID);
-
+  /*
   gribbuffersize = datasize*4+3000;
   gribbuffer = (unsigned char *) malloc(gribbuffersize);
-
+  */
 #if  defined  (HAVE_LIBCGRIBEX)
   if ( filetype == FILETYPE_GRB )
     {
@@ -569,7 +573,7 @@ int grbWriteVarSliceDP(int streamID, int varID, int levelID, const double *data,
     }
 
   nbytes = grbEncode(filetype, varID, levelID, vlistID, gridID, zaxisID, date, time, tsteptype, numavg, 
-		     datasize, data, nmiss, gribbuffer, gribbuffersize, ljpeg, gc);
+		     datasize, data, nmiss, &gribbuffer, ljpeg, gc);
 
   if ( streamptr->comptype == COMPRESS_SZIP )
     nbytes = grbSzip(filetype, gribbuffer, nbytes);
