@@ -375,7 +375,7 @@ void iegDefLevel(int *pdb, int *gdb, double *vct, int zaxisID, int levelID)
 
   if ( leveltype == ZAXIS_GENERIC )
     {
-      Message("Changed zaxis type from %s to %s\n",
+      Message("Changed zaxis type from %s to %s",
 	      zaxisNamePtr(leveltype),
 	      zaxisNamePtr(ZAXIS_PRESSURE));
       leveltype = ZAXIS_PRESSURE;
@@ -815,6 +815,7 @@ void iegAddRecord(int streamID, int param, int *pdb, int *gdb, double *vct,
 	    varID, gridID, levelID);
 }
 
+#if 0
 static
 void iegCmpRecord(int streamID, int tsID, int recID, off_t position, int param,
 		  int level, int xsize, int ysize)
@@ -844,7 +845,7 @@ void iegCmpRecord(int streamID, int tsID, int recID, off_t position, int param,
   if ( CDI_Debug )
     Message("varID = %d levelID = %d", varID, levelID);
 }
-
+#endif
 
 void iegDateTime(int *pdb, int *date, int *time)
 {
@@ -1326,7 +1327,7 @@ int iegScanTimestep(int streamID)
 
   if ( nrecs > 0 && nrecs < streamptr->tsteps[tsID].nrecs )
     {
-      Warning("Incomplete timestep. Stop scanning at timestep %d.\n", tsID);
+      Warning("Incomplete timestep. Stop scanning at timestep %d.", tsID);
       streamptr->ntsteps = tsID;
     }
 
@@ -1469,7 +1470,6 @@ void iegWriteVarDP(int streamID, int varID, const double *data)
   int fileID;
   int levID, nlevs, gridID, gridsize;
   int zaxisID;
-  double level;
   int datatype;
   int tsID;
   int vlistID;
@@ -1525,7 +1525,6 @@ void iegWriteVarDP(int streamID, int varID, const double *data)
 
       iegp->refval = refval;
 
-      /*  header[1] = (int) level; */
       iegDefDataDP(iegp, &data[levID*gridsize]);
       iegWrite(fileID, iegp);
     }
@@ -1572,3 +1571,12 @@ void iegWriteVarSliceDP(int streamID, int varID, int levID, const double *data)
 }
 
 #endif /* HAVE_LIBIEG */
+/*
+ * Local Variables:
+ * c-file-style: "Java"
+ * c-basic-offset: 2
+ * indent-tabs-mode: nil
+ * show-trailing-whitespace: t
+ * require-trailing-newline: t
+ * End:
+ */
