@@ -58,6 +58,8 @@ char *strdup(const char *s);
 #endif
 
 
+#define check_parg(arg)  if ( arg == 0 ) Warning("Argument '" #arg "' not allocated!")
+
 #if defined (__xlC__) /* performance problems on IBM */
 #ifndef DBL_IS_NAN
 #  define DBL_IS_NAN(x)     ((x) != (x))
@@ -236,13 +238,12 @@ typedef struct {
   int       unreduced;
   int       sortname;
   int       have_missval;
-  int       ztype;
-  int       zlevel;
+  int       comptype;      // compression type
+  int       complevel;     // compression level
   int       curfile;
   int       nfiles;
   char    **fnames;
-  int       gribHandleNums;
-  void    **gribHandle;
+  void     *gribContainers;
 }
 stream_t;
 
@@ -308,3 +309,12 @@ int getByteswap(int byteorder);
 
 
 #endif  /* _STREAM_INT_H */
+/*
+ * Local Variables:
+ * c-file-style: "Java"
+ * c-basic-offset: 2
+ * indent-tabs-mode: nil
+ * show-trailing-whitespace: t
+ * require-trailing-newline: t
+ * End:
+ */
