@@ -227,7 +227,7 @@ int srvDefRecord(int streamID)
       xsize = gridInqSize(gridID);
       ysize = 1;
     }
-  if ( gridInqType(gridID) == GRID_CELL ) ysize = 1;
+  if ( gridInqType(gridID) == GRID_UNSTRUCTURED ) ysize = 1;
   if ( gridInqSize(gridID) != xsize*ysize )
     Error("Internal problem with gridsize!");
 
@@ -809,7 +809,7 @@ int srvScanTimestep(int streamID)
 
   if ( nrecs > 0 && nrecs < streamptr->tsteps[tsID].nrecs )
     {
-      Warning("Incomplete timestep. Stop scanning at timestep %d.\n", tsID);
+      Warning("Incomplete timestep. Stop scanning at timestep %d.", tsID);
       streamptr->ntsteps = tsID;
     }
 
@@ -996,7 +996,7 @@ void srvWriteVarDP(int streamID, int varID, const double *data)
       xsize = gridInqSize(gridID);
       ysize = 1;
     }
-  if ( gridInqType(gridID) == GRID_CELL ) ysize = 1;
+  if ( gridInqType(gridID) == GRID_UNSTRUCTURED ) ysize = 1;
   if ( gridInqSize(gridID) != xsize*ysize )
     Error("Internal problem with gridsize!");
 
@@ -1063,7 +1063,7 @@ void srvWriteVarSliceDP(int streamID, int varID, int levID, const double *data)
       xsize = gridInqSize(gridID);
       ysize = 1;
     }
-  if ( gridInqType(gridID) == GRID_CELL ) ysize = 1;
+  if ( gridInqType(gridID) == GRID_UNSTRUCTURED ) ysize = 1;
   if ( gridInqSize(gridID) != xsize*ysize )
     Error("Internal problem with gridsize!");
 
@@ -1082,3 +1082,12 @@ void srvWriteVarSliceDP(int streamID, int varID, int levID, const double *data)
 }
 
 #endif /* HAVE_LIBSERVICE */
+/*
+ * Local Variables:
+ * c-file-style: "Java"
+ * c-basic-offset: 2
+ * indent-tabs-mode: nil
+ * show-trailing-whitespace: t
+ * require-trailing-newline: t
+ * End:
+ */
