@@ -17,35 +17,38 @@ void vlistvarInitEntry(int vlistID, int varID)
 
   vlistptr = vlist_to_pointer(vlistID);
 
-  vlistptr->vars[varID].fvarID       = varID;
-  vlistptr->vars[varID].mvarID       = varID;
-  vlistptr->vars[varID].flag         = 0;
-  vlistptr->vars[varID].param        = 0;
-  vlistptr->vars[varID].timeID       = CDI_UNDEFID;
-  vlistptr->vars[varID].datatype     = CDI_UNDEFID;
-  vlistptr->vars[varID].tsteptype    = TSTEP_INSTANT;
-  vlistptr->vars[varID].timave       = 0;
-  vlistptr->vars[varID].timaccu      = 0;
-  vlistptr->vars[varID].xyz          = 0;
-  vlistptr->vars[varID].gridID       = CDI_UNDEFID;
-  vlistptr->vars[varID].zaxisID      = CDI_UNDEFID;
-  vlistptr->vars[varID].instID       = CDI_UNDEFID;
-  vlistptr->vars[varID].modelID      = CDI_UNDEFID;
-  vlistptr->vars[varID].tableID      = CDI_UNDEFID;
-  vlistptr->vars[varID].missvalused  = FALSE;
-  vlistptr->vars[varID].missval      = cdiDefaultMissval;
-  vlistptr->vars[varID].addoffset    = 0.0;
-  vlistptr->vars[varID].scalefactor  = 1.0;
-  vlistptr->vars[varID].name         = NULL;
-  vlistptr->vars[varID].longname     = NULL;
-  vlistptr->vars[varID].stdname      = NULL;
-  vlistptr->vars[varID].units        = NULL;
-  vlistptr->vars[varID].nlevs        = 0;
-  vlistptr->vars[varID].levinfo      = NULL;
-  vlistptr->vars[varID].comptype     = COMPRESS_NONE;
-  vlistptr->vars[varID].complevel    = 1;
-  vlistptr->vars[varID].atts.nalloc  = MAX_ATTRIBUTES;
-  vlistptr->vars[varID].atts.nelems  = 0;
+  vlistptr->vars[varID].fvarID        = varID;
+  vlistptr->vars[varID].mvarID        = varID;
+  vlistptr->vars[varID].flag          = 0;
+  vlistptr->vars[varID].param         = 0;
+  vlistptr->vars[varID].timeID        = CDI_UNDEFID;
+  vlistptr->vars[varID].datatype      = CDI_UNDEFID;
+  vlistptr->vars[varID].tsteptype     = TSTEP_INSTANT;
+  vlistptr->vars[varID].timave        = 0;
+  vlistptr->vars[varID].timaccu       = 0;
+  vlistptr->vars[varID].xyz           = 0;
+  vlistptr->vars[varID].gridID        = CDI_UNDEFID;
+  vlistptr->vars[varID].zaxisID       = CDI_UNDEFID;
+  vlistptr->vars[varID].instID        = CDI_UNDEFID;
+  vlistptr->vars[varID].modelID       = CDI_UNDEFID;
+  vlistptr->vars[varID].tableID       = CDI_UNDEFID;
+  vlistptr->vars[varID].missvalused   = FALSE;
+  vlistptr->vars[varID].missval       = cdiDefaultMissval;
+  vlistptr->vars[varID].addoffset     = 0.0;
+  vlistptr->vars[varID].scalefactor   = 1.0;
+  vlistptr->vars[varID].name          = NULL;
+  vlistptr->vars[varID].longname      = NULL;
+  vlistptr->vars[varID].stdname       = NULL;
+  vlistptr->vars[varID].units         = NULL;
+  vlistptr->vars[varID].nlevs         = 0;
+  vlistptr->vars[varID].levinfo       = NULL;
+  vlistptr->vars[varID].comptype      = COMPRESS_NONE;
+  vlistptr->vars[varID].complevel     = 1;
+  vlistptr->vars[varID].atts.nalloc   = MAX_ATTRIBUTES;
+  vlistptr->vars[varID].atts.nelems   = 0;
+  vlistptr->vars[varID].lvalidrange   = 0;
+  vlistptr->vars[varID].validrange[0] = VALIDMISS;
+  vlistptr->vars[varID].validrange[1] = VALIDMISS;
 }
 
 static
@@ -510,7 +513,7 @@ const char *vlistInqVarUnitsPtr(int vlistID, int varID)
     @Item  varID    Variable identifier.
     @Item  name     Returned variable name. The caller must allocate space for the 
                     returned string. The maximum possible length, in characters, of
-                    the string is given by the predefined constant CDI_MAX_NAME.
+                    the string is given by the predefined constant @func{CDI_MAX_NAME}.
 
 @Description
 The function @func{vlistInqVarName} returns the name of a variable.
@@ -564,7 +567,7 @@ void vlistInqVarName(int vlistID, int varID, char *name)
     @Item  varID    Variable identifier.
     @Item  longname Long name of the variable. The caller must allocate space for the 
                     returned string. The maximum possible length, in characters, of
-                    the string is given by the predefined constant CDI_MAX_NAME.
+                    the string is given by the predefined constant @func{CDI_MAX_NAME}.
 
 @Description
 The function @func{vlistInqVarLongname} returns the longname of a variable if available,
@@ -616,7 +619,7 @@ void vlistInqVarLongname(int vlistID, int varID, char *longname)
     @Item  varID    Variable identifier.
     @Item  stdname  Standard name of the variable. The caller must allocate space for the 
                     returned string. The maximum possible length, in characters, of
-                    the string is given by the predefined constant CDI_MAX_NAME.
+                    the string is given by the predefined constant @func{CDI_MAX_NAME}.
 
 @Description
 The function @func{vlistInqVarStdname} returns the standard name of a variable if available,
@@ -655,7 +658,7 @@ void vlistInqVarStdname(int vlistID, int varID, char *stdname)
     @Item  varID    Variable identifier.
     @Item  units    Units of the variable. The caller must allocate space for the 
                     returned string. The maximum possible length, in characters, of
-                    the string is given by the predefined constant CDI_MAX_NAME.
+                    the string is given by the predefined constant @func{CDI_MAX_NAME}.
 
 @Description
 The function @func{vlistInqVarUnits} returns the units of a variable if available,
@@ -1076,30 +1079,6 @@ double vlistInqVarMissval(int vlistID, int varID)
   return (vlistptr->vars[varID].missval);
 }
 
-
-double vlistInqVarScalefactor(int vlistID, int varID)
-{
-  vlist_t *vlistptr;
-
-  vlistptr = vlist_to_pointer(vlistID);
-
-  vlistCheckVarID(__func__, vlistID, varID);
-
-  return (vlistptr->vars[varID].scalefactor);
-}
-
-
-double vlistInqVarAddoffset(int vlistID, int varID)
-{
-  vlist_t *vlistptr;
-
-  vlistptr = vlist_to_pointer(vlistID);
-
-  vlistCheckVarID(__func__, vlistID, varID);
-
-  return (vlistptr->vars[varID].addoffset);
-}
-
 /*
 @Function  vlistDefVarMissval
 @Title     Define the missing value of a Variable
@@ -1128,6 +1107,61 @@ void vlistDefVarMissval(int vlistID, int varID, double missval)
 }
 
 
+int vlistInqVarValidrange(int vlistID, int varID, double *validrange)
+{
+  vlist_t *vlistptr;
+
+  vlistptr = vlist_to_pointer(vlistID);
+
+  vlistCheckVarID(__func__, vlistID, varID);
+
+  if ( validrange != NULL && vlistptr->vars[varID].lvalidrange )
+    {
+      validrange[0] = vlistptr->vars[varID].validrange[0];
+      validrange[1] = vlistptr->vars[varID].validrange[1];
+    }
+
+  return (vlistptr->vars[varID].lvalidrange);
+}
+
+
+void vlistDefVarValidrange(int vlistID, int varID, const double *validrange)
+{
+  vlist_t *vlistptr;
+
+  vlistptr = vlist_to_pointer(vlistID);
+
+  vlistCheckVarID(__func__, vlistID, varID);
+
+  vlistptr->vars[varID].validrange[0] = validrange[0];
+  vlistptr->vars[varID].validrange[1] = validrange[1];
+  vlistptr->vars[varID].lvalidrange = TRUE;
+}
+
+
+double vlistInqVarScalefactor(int vlistID, int varID)
+{
+  vlist_t *vlistptr;
+
+  vlistptr = vlist_to_pointer(vlistID);
+
+  vlistCheckVarID(__func__, vlistID, varID);
+
+  return (vlistptr->vars[varID].scalefactor);
+}
+
+
+double vlistInqVarAddoffset(int vlistID, int varID)
+{
+  vlist_t *vlistptr;
+
+  vlistptr = vlist_to_pointer(vlistID);
+
+  vlistCheckVarID(__func__, vlistID, varID);
+
+  return (vlistptr->vars[varID].addoffset);
+}
+
 void vlistDefVarScalefactor(int vlistID, int varID, double scalefactor)
 {
   vlist_t *vlistptr;
