@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2011 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2012 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -28,18 +28,20 @@
  * number of contributing values during summation.
  */
 
-enum T_EIGEN_MODE {JACOBI, DANIELSON_LANCZOS};
-
-#define WEIGHTS 1
+#if defined (_OPENMP)
+#include <omp.h>
+#endif
 
 #include "cdi.h"
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
 #include "statistic.h"
-#if defined (_OPENMP)
-#include "omp.h"
-#endif
+
+
+enum T_EIGEN_MODE {JACOBI, DANIELSON_LANCZOS};
+
+#define WEIGHTS 1
 
 // NO MISSING VALUE SUPPORT ADDED SO FAR
 
