@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2010 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2011 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -23,6 +23,9 @@
       Filter    bandpass
 */
 
+#if defined ( _USE_FFTW3 ) 
+#include <fftw3.h>
+#endif
 
 #include <cdi.h>
 #include "cdo.h"
@@ -129,11 +132,36 @@ void create_fmasc(int nts, double fdata, double fmin, double fmax, int *fmasc)
   
 }
 
+
+#if defined ( _USE_FFTW3 ) 
 static
-void filter(int nts, const int *fmasc, double *array1, double *array2)
+void filter_fftw(int nts, const int *fmasc, 
+	    fftw_complex *fft_in, fftw_complex *fft_out, fftw_plan *p_T2S, fftw_plan *p_S2T)
 {  
+  //  fprintf(stderr,"using fftw filter\n");
+
   int i;
 
+  fftw_execute(*p_T2S);
+
+  for ( i = 0; i < nts; i++ )
+    if ( ! fmasc[i] )   {
+      fft_out[i][0] = 0;
+      fft_out[i][1] = 0;
+    }
+  
+  fftw_execute(*p_S2T);
+  
+  return;
+}
+
+#else 
+
+static
+void filter_intrinsic(int nts, const int *fmasc, double *array1, double *array2)
+{  
+  int i;
+  
   fft2(array1, array2, nts, 1);
   for ( i = 0; i < nts; i++ )
     if ( ! fmasc[i] )  array1[i] = array2[i] = 0;
@@ -142,6 +170,7 @@ void filter(int nts, const int *fmasc, double *array1, double *array2)
   return;
 }
 
+#endif
 
 void *Filter(void *argument)
 {
@@ -161,7 +190,7 @@ void *Filter(void *argument)
   int vlistID1, vlistID2, taxisID1, taxisID2;
   int nmiss;
   int nvars, nlevel;
-  int *vdate = NULL, *vtime = NULL;
+  dtinfo_t *dtinfo = NULL;
   int tunit;
   int incperiod0, incunit0, incunit, dpy, calendar;
   int year0, month0, day0;
@@ -169,8 +198,13 @@ void *Filter(void *argument)
   double *array1, *array2;
   double fdata = 0;
   field_t ***vars = NULL;
-  double fmin, fmax;
+  double fmin = 0, fmax = 0;
   int *fmasc;
+#if defined ( _USE_FFTW3 ) 
+  fftw_plan p_T2S, p_S2T;
+  fftw_complex *out_fft;
+  fftw_complex *in_fft;
+#endif
   
   cdoInitialize(argument);
 
@@ -179,10 +213,9 @@ void *Filter(void *argument)
   cdoOperatorAdd("lowpass" ,  LOW,   0, NULL);
 
   operatorID = cdoOperatorID();
-  operfunc = cdoOperatorF1(operatorID);
+  operfunc   = cdoOperatorF1(operatorID);
   
   streamID1 = streamOpenRead(cdoStreamName(0));
-  if ( streamID1 < 0 ) cdiError(streamID1, "Open failed on %s", cdoStreamName(0));
 
   vlistID1 = streamInqVlist(streamID1);
   vlistID2 = vlistDuplicate(vlistID1);
@@ -196,7 +229,6 @@ void *Filter(void *argument)
   dpy = calendar_dpy(calendar); /* should be 365 !!! */
   
   streamID2 = streamOpenWrite(cdoStreamName(1), cdoFiletype());
-  if ( streamID2 < 0 ) cdiError(streamID2, "Open failed on %s", cdoStreamName(1));
   
   streamDefVlist(streamID2, vlistID2);
   
@@ -208,14 +240,12 @@ void *Filter(void *argument)
       if ( tsID >= nalloc )
         {
           nalloc += NALLOC_INC;
-          vdate = (int *) realloc(vdate, nalloc*sizeof(int));
-          vtime = (int *) realloc(vtime, nalloc*sizeof(int));
-          vars  = (field_t ***) realloc(vars, nalloc*sizeof(field_t **));
+	  dtinfo = (dtinfo_t *)  realloc(dtinfo, nalloc*sizeof(dtinfo_t));
+          vars   = (field_t ***) realloc(vars,   nalloc*sizeof(field_t **));
         }
                        
-      vdate[tsID] = taxisInqVdate(taxisID1);
-      vtime[tsID] = taxisInqVtime(taxisID1);
-           
+      taxisInqDTinfo(taxisID1, &dtinfo[tsID]);
+   
       vars[tsID] = (field_t **) malloc(nvars*sizeof(field_t *));
       
       for ( varID = 0; varID < nvars; varID++ )
@@ -253,18 +283,18 @@ void *Filter(void *argument)
 	  int incperiod = 0;
 	  int year, month, day;
 
-          cdiDecodeDate(vdate[tsID],   &year,  &month,  &day);
-	  cdiDecodeDate(vdate[tsID-1], &year0, &month0, &day0);               
+          cdiDecodeDate(dtinfo[tsID].v.date,   &year,  &month,  &day);
+	  cdiDecodeDate(dtinfo[tsID-1].v.date, &year0, &month0, &day0);               
 
-          juldate0 = juldate_encode(calendar, vdate[tsID-1], vtime[tsID-1]);        
-          juldate  = juldate_encode(calendar, vdate[tsID], vtime[tsID]);         
+          juldate0 = juldate_encode(calendar, dtinfo[tsID-1].v.date, dtinfo[tsID-1].v.time);        
+          juldate  = juldate_encode(calendar, dtinfo[tsID].v.date, dtinfo[tsID].v.time);         
           jdelta   = juldate_to_seconds(juldate_sub(juldate, juldate0));
           
           if ( tsID == 1 ) 
             {           
               /*printf("%4i %4.4i-%2.2i-%2.2i\n", tsID, year, month, day);
               printf("    %4.4i-%2.2i-%2.2i\n",     year0,month0,day0);*/
-              getTimeInc(jdelta, vdate[tsID-1], vdate[tsID], &incperiod0, &incunit0);
+              getTimeInc(jdelta, dtinfo[tsID-1].v.date, dtinfo[tsID].v.date, &incperiod0, &incunit0);
               incperiod = incperiod0; 
               if ( incperiod == 0 ) cdoAbort("Time step must be different from zero\n");
               incunit = incunit0;
@@ -272,7 +302,7 @@ void *Filter(void *argument)
               fdata = 1.*iunits[incunit]/incperiod;
             }
           else 
-            getTimeInc(jdelta, vdate[tsID-1], vdate[tsID], &incperiod, &incunit);  
+            getTimeInc(jdelta, dtinfo[tsID-1].v.date, dtinfo[tsID].v.date, &incperiod, &incunit);  
         
 
 	  if ( incunit0 < 4 && month == 2 && day == 29 && 
@@ -292,6 +322,15 @@ void *Filter(void *argument)
   nts = tsID;
   /*  round up nts to next power of two for (better) performance 
    ** of fast fourier transformation */
+#if defined ( _USE_FFTW3 ) 
+  nts2 = nts;
+
+  out_fft = (fftw_complex *) malloc ( nts * sizeof(fftw_complex) );
+  in_fft  = (fftw_complex *) malloc ( nts * sizeof(fftw_complex) );
+
+  p_T2S = fftw_plan_dft_1d(nts,in_fft,out_fft,  1, FFTW_ESTIMATE);
+  p_S2T = fftw_plan_dft_1d(nts,out_fft,in_fft, -1, FFTW_ESTIMATE);
+#else 
   nts2 = nts-1;
   nts2 |= nts2 >> 1;  /* handle  2 bit numbers */
   nts2 |= nts2 >> 2;  /* handle  4 bit numbers */
@@ -299,9 +338,11 @@ void *Filter(void *argument)
   nts2 |= nts2 >> 8;  /* handle 16 bit numbers */
   nts2 |= nts2 >> 16; /* handle 32 bit numbers */
   nts2++;
-  
+
   array1 = (double *) malloc(nts2*sizeof(double));
   array2 = (double *) malloc(nts2*sizeof(double));
+#endif
+
   fmasc  = (int *) calloc(nts2, sizeof(int));
    
   for ( tsID = 0; tsID < nts; tsID++ ) array2[tsID] = 0;
@@ -333,7 +374,7 @@ void *Filter(void *argument)
     }      
   }
   
-  create_fmasc(nts2, fdata, fmin, fmax, fmasc); 
+  create_fmasc(nts, fdata, fmin, fmax, fmasc); 
 
   for ( varID = 0; varID < nvars; varID++ )
     {
@@ -341,34 +382,51 @@ void *Filter(void *argument)
       missval  = vlistInqVarMissval(vlistID1, varID);
       gridsize = gridInqSize(gridID);
       nlevel   = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID));
+
+#if defined ( _USE_FFTW3 ) 
+      fprintf(stderr," using fftw lib\n");
+#endif
+      
       for ( levelID = 0; levelID < nlevel; levelID++ )
         { 
-          for ( i = 0; i < gridsize; i+=2 )
+#if defined ( _USE_FFTW3 ) 
+          for ( i = 0; i < gridsize-1; i++ )
             {
               for ( tsID = 0; tsID < nts; tsID++ )                              
                 {
-                  array1[tsID] = vars[tsID][varID][levelID].ptr[i];                                         
-                  if ( i < gridsize - 1 )                 
-                    array2[tsID] = vars[tsID][varID][levelID].ptr[i+1];
-                }
+		  in_fft[tsID][0] = vars[tsID][varID][levelID].ptr[i];
+		  // in_fft[tsID][1] = vars[tsID][varID][levelID].ptr[i+1];
+		  in_fft[tsID][1] = 0;
+		}
 
-              /* zero padding up to next power of to */
-              for ( tsID = nts; tsID < nts2; tsID++ )                
-                {
-                  array1[tsID] = 0;       
-                  array2[tsID] = 0;
-                }
-                            
-              filter(nts2, fmasc, array1, array2);                         
+	      filter_fftw(nts,fmasc,in_fft,out_fft,&p_T2S,&p_S2T);
 
               for ( tsID = 0; tsID < nts; tsID++ )
-                {
-                  vars[tsID][varID][levelID].ptr[i] = array1[tsID];  
-                  if ( i < gridsize - 1 )
-                    vars[tsID][varID][levelID].ptr[i+1] = array2[tsID];
-                }
-            }
-        }
+		{
+		  vars[tsID][varID][levelID].ptr[i]   = in_fft[tsID][0] / nts;  
+		  //		  vars[tsID][varID][levelID].ptr[i+1] = in_fft[tsID][1] / nts;  
+		}
+	    }
+#else 
+	  for ( i = 0; i < gridsize; i++ )  
+	    {
+	      // for some reason, the optimization using the complex transform independent of the 
+	      // real one in order to transform two time series at the same time does not work
+	      // properly here. 
+
+	      memset( array2,0,nts2*sizeof(double) );
+	      for ( tsID = 0; tsID < nts; tsID++ )
+		array1[tsID] = vars[tsID][varID][levelID].ptr[i];                                         
+	      /* zero padding up to next power of to */
+              for ( ; tsID < nts2; tsID++ )                
+		array1[tsID] = 0;       
+
+	      filter_intrinsic(nts2,fmasc,array1,array2);
+              for ( tsID = 0; tsID < nts; tsID++ )
+		vars[tsID][varID][levelID].ptr[i]   = array1[tsID];  
+	    }
+#endif
+	}
     }
   
   if ( array1 ) free(array1);
@@ -376,8 +434,7 @@ void *Filter(void *argument)
 
   for ( tsID = 0; tsID < nts; tsID++ )
     {
-      taxisDefVdate(taxisID2, vdate[tsID]);
-      taxisDefVtime(taxisID2, vtime[tsID]);
+      taxisDefDTinfo(taxisID2, dtinfo[tsID]);
       streamDefTimestep(streamID2, tsID);
     
       for ( varID = 0; varID < nvars; varID++ )
@@ -399,9 +456,8 @@ void *Filter(void *argument)
       free(vars[tsID]);
     }
 
-  if ( vars  ) free(vars);
-  if ( vdate ) free(vdate);
-  if ( vtime ) free(vtime);
+  if ( vars   ) free(vars);
+  if ( dtinfo ) free(dtinfo);
   
   streamClose(streamID2);
   streamClose(streamID1);
