@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2010 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2011 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -35,7 +35,6 @@
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
-#include "functs.h"
 #include "grid.h"
 
 
@@ -74,7 +73,8 @@ int genBoxGrid(int gridID1, int xinc, int yinc)
   if ( xinc < 1 || yinc < 1 )
     cdoAbort("xinc and yinc must not be smaller than 1!");
   
-  if ( gridtype == GRID_GAUSSIAN || gridtype == GRID_LONLAT || gridtype == GRID_CURVILINEAR )
+  if ( gridtype == GRID_GAUSSIAN || gridtype == GRID_LONLAT ||
+       gridtype == GRID_CURVILINEAR || gridtype == GRID_GENERIC )
     {
       nlon1 = gridInqXsize(gridID1);
       nlat1 = gridInqYsize(gridID1);
@@ -168,6 +168,9 @@ int genBoxGrid(int gridID1, int xinc, int yinc)
           free(grid1_corner_lat);
         }
     } /* if ( gridtype == GRID_GAUSSIAN || gridtype == GRID_LONLAT ) */
+  else if ( gridtype == GRID_GENERIC )
+    {
+    }
   else if ( gridtype == GRID_CURVILINEAR )
     {
       
@@ -183,7 +186,7 @@ int genBoxGrid(int gridID1, int xinc, int yinc)
 
       /* Convert lat/lon units if required */
       {
-	char units[128];
+	char units[CDI_MAX_NAME];
 	gridInqXunits(gridID1, units);
 	gridToDegree(units, "grid center lon", nlon1*nlat1, xvals1);
 	gridInqYunits(gridID1, units);
@@ -201,7 +204,7 @@ int genBoxGrid(int gridID1, int xinc, int yinc)
 
 	  /* Convert lat/lon units if required */
 	  {
-	    char units[128];
+	    char units[CDI_MAX_NAME];
 	    gridInqXunits(gridID1, units);
 	    gridToDegree(units, "grid corner lon", 4*nlon1*nlat1, grid1_corner_lon);
 	    gridInqYunits(gridID1, units);
@@ -292,7 +295,7 @@ int genBoxGrid(int gridID1, int xinc, int yinc)
                               /* lower right cell */
                               if ( ( y1 == (y2+1)*yinc -1 ) && (x1 == (x2+1)*xinc -1) )
                                 {
-                                  for ( corner = 0; corner < 4; corner ++ )
+                                  for ( corner = 0; corner < 4; corner++ )
                                     {                             
                                   add = 4*g1_add + corner;
                                       if ( grid1_corner_lon[add] > ox_lo )
@@ -305,7 +308,7 @@ int genBoxGrid(int gridID1, int xinc, int yinc)
                               /* lower left cell */
                               if ( ( y1 == (y2+1)*yinc -1 ) && ( x1 == x2*xinc ) )
                                 {    
-                                  for ( corner = 0; corner < 4; corner ++ )
+                                  for ( corner = 0; corner < 4; corner++ )
                                     {
                                       add = 4*g1_add + corner;
                                       if ( grid1_corner_lon[add] < on_lo )
@@ -656,7 +659,6 @@ void *Gridboxstat(void *argument)
     needWeights = TRUE;
 
   streamID1 = streamOpenRead(cdoStreamName(0));
-  if ( streamID1 < 0 ) cdiError(streamID1, "Open failed on %s", cdoStreamName(0));
 
   vlistID1 = streamInqVlist(streamID1);
   vlistID2 = vlistDuplicate(vlistID1);
@@ -677,7 +679,6 @@ void *Gridboxstat(void *argument)
     vlistChangeGridIndex(vlistID2, index, gridID2);
 
   streamID2 = streamOpenWrite(cdoStreamName(1), cdoFiletype());
-  if ( streamID2 < 0 ) cdiError(streamID2, "Open failed on %s", cdoStreamName(1));
 
   streamDefVlist(streamID2, vlistID2);
 
