@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2010 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2011 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -29,6 +29,93 @@
 #include "util.h"
 
 
+static
+void checkDupEntry(int vlistID1, int vlistID2, const char *filename)
+{
+  char vname1[CDI_MAX_NAME], vname2[CDI_MAX_NAME];
+  int k;
+  int gridID1, gridID2;
+  int zaxisID1, zaxisID2;
+  int varID1, varID2;
+  int nvars1, nvars2;
+  int param1, param2;
+  int ztype1, ztype2;
+  int gtype1, gtype2;
+  int nlev1,  nlev2;
+  int gsize1, gsize2;
+  int mlev1 = 0, mlev2 = 0;
+  double *lev1 = NULL, *lev2 = NULL;
+
+  nvars1 = vlistNvars(vlistID1);
+  nvars2 = vlistNvars(vlistID2);
+
+  for ( varID1 = 0; varID1 < nvars1; ++varID1 )
+    {
+      vlistInqVarName(vlistID1, varID1, vname1);
+      param1   = vlistInqVarParam(vlistID1, varID1);
+      gridID1  = vlistInqVarGrid(vlistID1, varID1);
+      zaxisID1 = vlistInqVarZaxis(vlistID1, varID1);
+      gtype1   = gridInqType(gridID1);
+      gsize1   = gridInqSize(gridID1);
+      ztype1   = zaxisInqType(zaxisID1);
+      nlev1    = zaxisInqSize(zaxisID1);
+      if ( nlev1 > mlev1 )
+	{
+	  mlev1 = nlev1;
+	  lev1 = (double *) realloc(lev1, mlev1*sizeof(double));
+	}
+      zaxisInqLevels(zaxisID1, lev1);
+
+      for ( varID2 = 0; varID2 < nvars2; ++varID2 )
+	{
+	  vlistInqVarName(vlistID2, varID2, vname2);
+	  param2   = vlistInqVarParam(vlistID2, varID2);
+	  gridID2  = vlistInqVarGrid(vlistID2, varID2);
+	  zaxisID2 = vlistInqVarZaxis(vlistID2, varID2);
+	  gtype2   = gridInqType(gridID2);
+	  gsize2   = gridInqSize(gridID2);
+	  ztype2   = zaxisInqType(zaxisID2);
+	  nlev2    = zaxisInqSize(zaxisID2);
+	  if ( gtype1 == gtype2 && gsize1 == gsize2 && ztype1 == ztype2 && nlev1 == nlev2 )
+	    {
+	      if ( nlev2 > mlev2 )
+		{
+		  mlev2 = nlev2;
+		  lev2 = (double *) realloc(lev2, mlev2*sizeof(double));
+		}
+	      zaxisInqLevels(zaxisID2, lev2);
+
+	      for ( k = 0; k < nlev2; ++k )
+		if ( !IS_EQUAL(lev1[k], lev2[k]) ) break;
+
+	      if ( k == nlev2 )
+		{
+		  if ( param1 < 0 || param2 < 0 )
+		    {
+		      if ( strcmp(vname1, vname2) == 0 )
+			{
+			  cdoWarning("Duplicate entry of parameter %s in %s!", vname2, filename);
+			}
+		    }
+		  else
+		    {
+		      if ( param1 == param2 )
+			{
+			  char paramstr[32];
+			  cdiParamToString(param2, paramstr, sizeof(paramstr));
+			  cdoWarning("Duplicate entry of parameter %s in %s!", paramstr, filename);
+			}
+		    }
+		}
+	    }
+	}
+    }
+
+  if ( lev1 ) free(lev1);
+  if ( lev2 ) free(lev2);
+}
+
+
 void *Merge(void *argument)
 {
   int streamID1 = -1, streamID2 = -1;
@@ -59,7 +146,7 @@ void *Merge(void *argument)
 
   ofilename = cdoStreamName(streamCnt-1);
 
-  if ( !cdoSilentMode )
+  if ( !cdoSilentMode && !cdoOverwriteMode )
     if ( fileExist(ofilename) )
       if ( !userFileOverwrite(ofilename) )
 	cdoAbort("Outputfile %s already exist!", ofilename);
@@ -70,7 +157,6 @@ void *Merge(void *argument)
   for ( index = 0; index < nmerge; index++ )
     {
       streamID1 = streamOpenRead(cdoStreamName(index));
-      if ( streamID1 < 0 ) cdiError(streamID1, "Open failed on %s", cdoStreamName(index));
 
       streamIDs[index] = streamID1;
 
@@ -84,8 +170,12 @@ void *Merge(void *argument)
 
   vlistID2 = vlistCreate();
   vlistCopy(vlistID2, vlistIDs[0]);
-  /*  for ( index = 1; index < nmerge; index++ ) vlistCat(vlistID2, vlistIDs[index]); */
-  for ( index = 1; index < nmerge; index++ ) vlistMerge(vlistID2, vlistIDs[index]);
+  for ( index = 1; index < nmerge; index++ )
+    {
+      checkDupEntry(vlistID2, vlistIDs[index], cdoStreamName(index));
+      /* vlistCat(vlistID2, vlistIDs[index]); */
+      vlistMerge(vlistID2, vlistIDs[index]);
+    }
 
   if ( cdoVerbose ) 
     {
@@ -94,7 +184,6 @@ void *Merge(void *argument)
     }
        
   streamID2 = streamOpenWrite(ofilename, cdoFiletype());
-  if ( streamID2 < 0 ) cdiError(streamID2, "Open failed on %s", ofilename);
 
   vlistDefTaxis(vlistID2, taxisID2);
   streamDefVlist(streamID2, vlistID2);
