@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2010 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2011 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -54,6 +54,7 @@ extern int cdoDefaultInstID;
 extern int cdoCheckDatarange;
 
 extern int cdoSilentMode;
+extern int cdoOverwriteMode;
 extern int cdoRegulargrid;
 extern int cdoBenchmark;
 extern int cdoTimer;
@@ -63,8 +64,8 @@ extern int cdoCompress;
 extern int cdoInteractive;
 extern int cdoParIO;
 
-extern int cdoZtype;
-extern int cdoZlevel;
+extern int cdoCompType;
+extern int cdoCompLevel;
 
 extern int cdoExpMode;
 
