@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2006 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2011 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -172,9 +172,15 @@ int args2intlist(int argc, char **argv, LIST *list)
     {
       split_intstring(argv[iarg], &first, &last, &inc);
 
-      for ( ival = first; ival <= last; ival += inc )
+      if ( inc >= 0 )
 	{
-	  listSetInt(list, nint++, ival);
+	  for ( ival = first; ival <= last; ival += inc )
+	    listSetInt(list, nint++, ival);
+	}
+      else
+	{
+	  for ( ival = first; ival >= last; ival += inc )
+	    listSetInt(list, nint++, ival);
 	}
     }
 
@@ -195,13 +201,18 @@ int args2fltlist(int argc, char **argv, LIST *list)
     {
       len = (int) strlen(argv[iarg]);
       for ( i = 0; i < len; i++ )
-	if ( argv[iarg][i] != '/' && ! isdigit(argv[iarg][i]) ) break;
+	if ( argv[iarg][i] != '/' && argv[iarg][i] != '-' && ! isdigit(argv[iarg][i]) ) break;
       
       if ( i != len )
 	{
-	  if      ( strcmp(argv[iarg],  "inf") == 0 ) tmp_val =  DBL_MAX;
-	  else if ( strcmp(argv[iarg], "-inf") == 0 ) tmp_val = -DBL_MAX;
-	  else                                        tmp_val = atof(argv[iarg]);
+	  /*
+	  if      ( strcmp(argv[iarg],  "inf") == 0 )
+	    tmp_val =  DBL_MAX;
+	  else if ( strcmp(argv[iarg], "-inf") == 0 )
+	    tmp_val = -DBL_MAX;
+	  else  
+	  */                                    
+	    tmp_val = atof(argv[iarg]);
 
 	  listSetFlt(list, nint++, tmp_val);
 	}
@@ -209,9 +220,15 @@ int args2fltlist(int argc, char **argv, LIST *list)
 	{
 	  split_intstring(argv[iarg], &first, &last, &inc);
 
-	  for ( ival = first; ival <= last; ival += inc )
+	  if ( inc >= 0 )
 	    {
-	      listSetFlt(list, nint++, (double) ival);
+	      for ( ival = first; ival <= last; ival += inc )
+		listSetFlt(list, nint++, (double) ival);
+	    }
+	  else
+	    {
+	      for ( ival = first; ival >= last; ival += inc )
+		listSetFlt(list, nint++, (double) ival);
 	    }
 	}
     }
