@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2010 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2012 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -33,7 +33,7 @@ void cdoProcessTime(double *utime, double *stime)
   struct tms tbuf;
   double clock_ticks = 0;
 
-  if ( times(&tbuf) == -1 )
+  if ( (int)times(&tbuf) == -1 )
     {
       *utime = 0;
       *stime = 0;
