@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2010 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2011 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -190,6 +190,8 @@ int zaxisFromFile(FILE *gfp)
 	    zaxis.type = ZAXIS_ISENTROPIC;
 	  else if ( memcmp(pline, "surface", 7)  == 0 )
 	    zaxis.type = ZAXIS_SURFACE;
+	  else if ( memcmp(pline, "generic", 7)  == 0 )
+	    zaxis.type = ZAXIS_GENERIC;
 	  else
 	    Warning("Invalid zaxisname : %s", pline);
 	}
